@@ -15,15 +15,18 @@ class Task(BaseModel):
     status = db.Column(db.Enum(StatusType), default=StatusType.pending, nullable=False)
     previous = db.Column(JSONBType, default=[])
     result = db.Column(PickleType)
+    is_hook = db.Column(db.Boolean, default=False)
 
     # Relationship
     workflow_id = db.Column(
         UUIDType(binary=False),
-        db.ForeignKey("workflows.id"),
+        db.ForeignKey("workflows.id", ondelete="cascade"),
         nullable=False,
         index=True,
     )
-    workflow = db.relationship("Workflow", backref=db.backref("tasks", lazy=True))
+    workflow = db.relationship(
+        "Workflow", backref=db.backref("tasks", lazy=True), cascade="all,delete"
+    )
 
     def __repr__(self):
         return f"<Task {self.key}>"
@@ -37,6 +40,7 @@ class Task(BaseModel):
                 "task": self.id,
                 "previous": self.previous,
                 "result": self.result,
+                "is_hook": self.is_hook,
             }
         )
         return d
